/**
 * JASMINe
 * Copyright (C) 2011 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: LewysCreateCommand.java 8733 2011-08-10 09:51:06Z danesa $
 * --------------------------------------------------------------------------
 */

package org.ow2.jasmine.probe.collectors.lewys.shell;

import org.apache.felix.ipojo.annotations.*;
import org.apache.felix.shell.Command;
import org.ow2.jasmine.probe.JasmineIndicator;
import org.ow2.jasmine.probe.JasmineProbeException;
import org.ow2.jasmine.probe.JasmineProbeManager;
import org.ow2.jasmine.probe.collectors.lewys.internal.LewysCollectorService;
import org.ow2.jasmine.probe.shell.JasmineProbeCommand;

import java.io.PrintStream;
import java.util.HashMap;
import java.util.Map;

/**
 * Command "lewys": create an indicator based on lewys collector
 * @author durieuxp
 */
@Component(name="LewysCreateCommand")
@Provides
public class LewysCreateCommand extends JasmineProbeCommand implements Command {

    /**
     * Type of indicator
     * Must be equal to : LewysCollectorService.indicatorType
     */
    private final static String indicatorType = "lewys";

    /**
     * command name
     */
    private String name = "indicator-lewys-create";

    /**
     * Example of possible options
     * necessary to be able to print out usage even when wrong options
     * are provided by the user.
     */
    private String requiredOptions = "-n indicatorName -c cpu -r a_resource";

    /**
     * command description
     */
    private String description = "create a lewys indicator";


    // ----------------------------------------------------------------------------
    // ipojo management
    // ----------------------------------------------------------------------------

    @Requires
    JasmineProbeManager probeManager = null;

    // ----------------------------------------------------------------------------
    // constructors
    // ----------------------------------------------------------------------------

    /**
     * Default Constructor
     */
    public LewysCreateCommand() {
        super();
        setParams(new LewysParams());
    }

    // ----------------------------------------------------------------------------
    // org.apache.felix.shell.Command implementation
    // ----------------------------------------------------------------------------

    /**
     * Returns the name of the command that is implemented by the interface.
     * The command name should not contain whitespace and should also be unique.
     * @return the name of the command.
     */
    public String getName() {
        return name;
    }

    /**
     * Returns a short description of the command; this description should be as short as possible.
     * This information is used when generating the command help information.
     * @return a short description of the command.
     */
    public String getShortDescription() {
        return description;
    }

    public String getRequiredOptions() {
        return requiredOptions;
    }

    public JasmineProbeManager getProbeManager() {
        return probeManager;
    }

    /**
     * Executes the command using the supplied command line, output print stream, and error print stream.
     * @param line the complete command line, including the command name.
     * @param out  the print stream to use for standard output.
     * @param err  the print stream to use for standard error.
     */
    public void execute(String line, PrintStream out, PrintStream err) {
        boolean validOptions = parseOptions(line, out, err);
        if (!validOptions) {
            err.println(getUsage());
            return;
        }

        LewysParams params = (LewysParams) getParams();

        // Create the JasmineIndicator
        JasmineIndicator indicator = new JasmineIndicator();
        indicator.setName(params.getName());
        indicator.setType(indicatorType);


        // set the rest of the properties
        Map<String, String> properties =  new HashMap<String, String>();
        properties.put(LewysCollectorService.PROP_CMD, params.getCmd());
        properties.put(LewysCollectorService.PROP_RESOURCES, params.getResources());
        indicator.setProperties(properties);

        // reset params
        params.reset();

        // Create the JasmineIndicator
        createIndicator(name, indicator, out, err);
    }

}
